%define major        27
%define libname      %mklibname %{name} %{major}
%define develname    %mklibname %{name} -d

%define cblasmajor   0
%define cblaslibname %mklibname %{name}cblas %{cblasmajor}

Summary:	The GNU Scientific Library for numerical analysis
Name:		gsl
Version:	2.7.1
Release:	%mkrel 2
License:	GPLv2+
Group:		Sciences/Mathematics
URL:		https://www.gnu.org/software/gsl/
Source0:	https://ftp.gnu.org/gnu/gsl/%{name}-%{version}.tar.gz
Source1:	https://ftp.gnu.org/gnu/gsl/%{name}-%{version}.tar.gz.sig
Patch0:		gsl-2.6-undefined-symbols.patch
Patch1:		gsl-test.patch
Patch2:		gsl-tol.patch

BuildRequires:	texinfo

%description
The GNU Scientific Library (GSL) is a numerical library for C and
C++ programmers.  It contains over 1000 mathematical routines written
in ANSI C.  The library follows modern coding conventions, and lends
itself to being used in very high level languages (VHLLs).

The library covers the following subject areas:

  Complex Numbers             Roots of Polynomials     Special Functions
  Vectors and Matrices        Permutations             Sorting
  BLAS Support                Linear Algebra           Eigensystems
  Fast Fourier Transforms     Quadrature               Random Numbers
  Quasi-Random Sequences      Random Distributions     Statistics
  Histograms                  N-Tuples                 Monte Carlo Integration
  Simulated Annealing         Differential Equations   Interpolation
  Numerical Differentiation   Chebyshev Approximation  Series Acceleration
  Discrete Hankel Transforms  Root-Finding             Minimization
  Least-Squares Fitting       Physical Constants       IEEE Floating-Point

Further information can be found in the GSL Reference Manual.

Install the gsl package if you need a library for high-level
scientific numerical analysis.

%package	progs
Summary:	Programs of the Scientific Library
Group:		Sciences/Mathematics
Requires:	%{libname} = %{version}-%{release}

%description	progs
Here are the GNU Scientific Library (GSL) programs:
 - gsl-histogram: computes a histogram of the data on stdin
                  using n bins from xmin to xmax.
 - gsl-randist: generates n samples from a given distribution DIST
                with given parameters

%package	doc
Summary:	Documentation of the Scientific Library
Group:		Documentation
BuildArch:	noarch

%description	doc
This is the documentation in info format of the GNU Scientific Library (GSL).
This doc can be viewed through info, pinfo, konqueror, gnome yelp, ...

%package -n	%{libname}
Summary:	Shared libraries for Scientific Library
Group:		System/Libraries

%description -n	%{libname}
The GNU Scientific Library (GSL) is a numerical library for C and
C++ programmers.  It contains over 1000 mathematical routines written
in ANSI C.  The library follows modern coding conventions, and lends
itself to being used in very high level languages (VHLLs).

 The library covers the following subject areas:

  Complex Numbers             Roots of Polynomials     Special Functions
  Vectors and Matrices        Permutations             Sorting
  BLAS Support                Linear Algebra           Eigensystems
  Fast Fourier Transforms     Quadrature               Random Numbers
  Quasi-Random Sequences      Random Distributions     Statistics
  Histograms                  N-Tuples                 Monte Carlo Integration
  Simulated Annealing         Differential Equations   Interpolation
  Numerical Differentiation   Chebyshev Approximation  Series Acceleration
  Discrete Hankel Transforms  Root-Finding             Minimization
  Least-Squares Fitting       Physical Constants       IEEE Floating-Point

Further information can be found in the GSL Reference Manual.


%package -n	%{cblaslibname}
Summary:	Shared libraries for Scientific Library
Group:		System/Libraries

%description -n	%{cblaslibname}
The GNU Scientific Library (GSL) cblas library.

%package -n	%{develname}
Summary:	Development files for Scientific Library
Group:		Development/C
Requires:	%{libname} = %{version}-%{release}
Requires:	%{cblaslibname} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
Provides:	lib%{name}-devel = %{version}-%{release}

%description -n	%{develname}
The gsl package includes the GNU Scientific Library (GSL). The GSL is a
collection of routines for numerical analysis, written in C.
It now includes a random number suite, an FFT package, simulated annealing
and root finding.  In the future, it will include numerical and Monte Carlo
integration and special functions.
Linking against the GSL allows programs to access functions which can
handle many of the problems encountered in scientific computing.

These are the static libs and include headers for developers.

%prep
%setup -q
%autopatch -p1

%build
autoreconf -fi

# disable FMA
%ifarch aarch64
export CFLAGS="%{optflags} -ffp-contract=off"
%endif

%configure --disable-static
%make_build

%check
%ifarch %arm %mips %ix86
# check is failing on arm probably due to double stuff
# I wouldn't be surprised that mips is affected too.
make check || /bin/true
%else
if ! make check; then
	for log in */*.log; do
		echo "===   $log   ==="
		cat $log
		echo "===  /$log   ==="
	done
	exit 1
fi
%endif

%install
%make_install

find %{buildroot} -name '*.la' -delete

%files progs
%doc AUTHORS NEWS README THANKS
%{_bindir}/gsl-histogram
%{_bindir}/gsl-randist
%{_mandir}/man1/gsl-histogram*
%{_mandir}/man1/gsl-randist*

%files doc
%{_infodir}/*info*

%files -n %{libname}
%{_libdir}/libgsl.so.%{major}{,.*}

%files -n %{cblaslibname}
%{_libdir}/libgslcblas.so.%{cblasmajor}{,.*}

%files -n %{develname}
%doc BUGS ChangeLog TODO doc/examples/
%{_bindir}/gsl-config
%{_datadir}/aclocal/*.m4
%{_includedir}/*
%{_libdir}/pkgconfig/*.pc
%{_libdir}/*.so
%{_mandir}/man3/*
%{_mandir}/man1/gsl-config.*


%changelog
* Sat Jun 28 2025 umeabot <umeabot> 2.7.1-2.mga10
+ Revision: 2216921
- Mageia 10 Mass Rebuild

* Thu Dec 29 2022 daviddavid <daviddavid> 2.7.1-1.mga9
+ Revision: 1927492
- new version: 2.7.1
- now lib major is 27

* Fri Mar 18 2022 umeabot <umeabot> 2.7-3.mga9
+ Revision: 1797611
- Mageia 9 Mass Rebuild

* Fri Oct 01 2021 joequant <joequant> 2.7-2.mga9
+ Revision: 1746992
- use cblas-devel for gslcblas-devel

* Sun Aug 08 2021 luigiwalser <luigiwalser> 2.7-1.mga9
+ Revision: 1740358
- 2.7

* Thu Aug 20 2020 ovitters <ovitters> 2.6-3.mga8
+ Revision: 1616888
- remove install-info scriptlets, rely on filetrigger instead (mga#27107)

* Sat Feb 15 2020 umeabot <umeabot> 2.6-2.mga8
+ Revision: 1529256
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Tue Aug 27 2019 daviddavid <daviddavid> 2.6-1.mga8
+ Revision: 1433240
- new version: 2.6
- now libmajor is 25

* Sun Dec 30 2018 luigiwalser <luigiwalser> 2.5-1.mga7
+ Revision: 1346785
- 2.5
- rediff patch 0

* Sun Sep 23 2018 umeabot <umeabot> 2.4-4.mga7
+ Revision: 1298087
- Mageia 7 Mass Rebuild

* Sun Jun 03 2018 wally <wally> 2.4-3.mga7
+ Revision: 1234025
- add test fix patches and aarch64 cflag fix from Fedora

* Sat Dec 09 2017 wally <wally> 2.4-2.mga7
+ Revision: 1181799
- revive patch to properly fix underlinking

* Sat Dec 09 2017 mjack <mjack> 2.4-1.mga7
+ Revision: 1181790
- Updated to version 2.4
- New major: 23

* Sat Sep 02 2017 tv <tv> 2.3-2.mga7
+ Revision: 1150570
- rebuild for new gcc-gfortran

* Sun Jan 01 2017 luigiwalser <luigiwalser> 2.3-1.mga6
+ Revision: 1078957
- 2.3

* Sat Sep 10 2016 luigiwalser <luigiwalser> 2.2.1-1.mga6
+ Revision: 1051250
- 2.2.1
- add a few additional fixes from upstream git

* Mon May 23 2016 tv <tv> 2.1-4.mga6
+ Revision: 1017911
- fix linking
- drop BR on libatlas-devel
- drop linkage to ATLAS, which is against the design of GSL (like FC did)
- rebuild for new atlas

* Tue Jan 26 2016 luigiwalser <luigiwalser> 2.1-3.mga6
+ Revision: 927797
- add conflicts to ease upgrade from libgsl0

* Tue Jan 26 2016 luigiwalser <luigiwalser> 2.1-2.mga6
+ Revision: 927674
- temporarily disable test suite on i586 (savannah#46593)
- BR texinfo for makeinfo command
- add upstream patches to try to fix test suite errors
- 2.1
- rediff patch 2
- remove upstream patch 3
- add subpackage for gslcblas library
- library major is now 19

* Wed Nov 12 2014 pterjan <pterjan> 1.16-5.mga5
+ Revision: 796672
- Add upstream patch fixing a test on some architectures (including i586)
- Display test logs when they fail
+ umeabot <umeabot>
- Second Mageia 5 Mass Rebuild
- Mageia 5 Mass Rebuild
+ tv <tv>
- use %%global for req/prov exclude
- autoconvert to new prov/req excludes

* Sat Oct 19 2013 umeabot <umeabot> 1.16-3.mga4
+ Revision: 531105
- Mageia 4 Mass Rebuild

* Thu Aug 01 2013 fwang <fwang> 1.16-2.mga4
+ Revision: 462007
- force to use atlas

* Thu Aug 01 2013 fwang <fwang> 1.16-1.mga4
+ Revision: 461989
- try using autoreconf
- atlas lib is no longer supported
- new version 1.16

* Sun Jun 02 2013 fwang <fwang> 1.15-7.mga4
+ Revision: 434579
- add atlas-devel as requires, as gsl-config produces -latlas

* Sun Apr 07 2013 mitya <mitya> 1.15-6.mga3
+ Revision: 408747
- Nuke bogus requires on -devel package

* Sun Apr 07 2013 mitya <mitya> 1.15-5.mga3
+ Revision: 408693
- Build with ATLAS for higher performance

* Wed Mar 27 2013 mitya <mitya> 1.15-4.mga3
+ Revision: 405432
- Make tests pass, apply odeinitval2 fix from upstream
+ tv <tv>
- make doc subpackage noarch
+ umeabot <umeabot>
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild
+ malo <malo>
- fix RPM group

* Sun Nov 27 2011 tv <tv> 1.15-1.mga2
+ Revision: 172540
- new release
+ rtp <rtp>
- Execute the testsuite but don't make it fail the build on arm/mips

* Thu Jan 20 2011 ahmad <ahmad> 1.14-3.mga1
+ Revision: 26023
- drop old/unneeded scriptlets
- imported package gsl


* Thu Dec 02 2010 Oden Eriksson <oeriksson@mandriva.com> 1.14-2mdv2011.0
+ Revision: 605501
- rebuild

* Sun Mar 21 2010 Tomasz Pawel Gajc <tpg@mandriva.org> 1.14-1mdv2010.1
+ Revision: 526233
- update to new version 1.14
- rediff patch 0

* Tue Mar 16 2010 Oden Eriksson <oeriksson@mandriva.com> 1.13-2mdv2010.1
+ Revision: 521131
- rebuilt for 2010.1

* Thu Sep 10 2009 Frederik Himpe <fhimpe@mandriva.org> 1.13-1mdv2010.0
+ Revision: 437127
- Update to new version 1.13

  + Funda Wang <fwang@mandriva.org>
    - rebuild with fPIC (bug#45668)

* Tue Feb 17 2009 Tomasz Pawel Gajc <tpg@mandriva.org> 1.12-1mdv2009.1
+ Revision: 342158
- fix tests by adjusting optflags (gcc bug #38478, should work with next upstream release)
- Patch0: rediff to meet nofuzz
- update to new version 1.12

  + Thierry Vignaud <tv@mandriva.org>
    - rebuild early 2009.0 package (before pixel changes)

* Tue Jun 10 2008 Helio Chissini de Castro <helio@mandriva.com> 1.11-3mdv2009.0
+ Revision: 217543
- Fix undefined symbol cblas.

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

* Fri Apr 18 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 1.11-1mdv2009.0
+ Revision: 195506
- new version
- do not package INSTALL file

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Tue Oct 16 2007 Tomasz Pawel Gajc <tpg@mandriva.org> 1.10-1mdv2008.1
+ Revision: 98786
- new version

* Tue Sep 18 2007 Tomasz Pawel Gajc <tpg@mandriva.org> 1.9-2mdv2008.0
+ Revision: 89853
- new devel library policy
- new license policy
- add checks
- spec file clean


* Thu Feb 22 2007 Tomasz Pawel Gajc <tpg@mandriva.org> 1.9-1mdv2007.0
+ Revision: 124788
- new version

* Wed Feb 14 2007 Tomasz Pawel Gajc <tpg@mandriva.org> 1.8-3mdv2007.1
+ Revision: 121136
- rebuild
- update url
- spec file clean
- Import gsl

* Sat Apr 29 2006 Olivier Blin <oblin@mandriva.com> 1.8-2mdk
- update description (thanks to Brian Gough for reminding gsl isn't in
  alpha development)

* Fri Apr 21 2006 Thierry Vignaud <tvignaud@mandriva.com> 1.8-1mdk
- new release

* Thu Nov 03 2005 Thierry Vignaud <tvignaud@mandriva.com> 1.7-1mdk
- new release

* Sat Sep 10 2005 Olivier Blin <oblin@mandriva.com> 1.6-3mdk
- fix typo in summary

* Thu Mar 31 2005 Per Øyvind Karlsen <peroyvind@linux-mandrake.com> 1.6-2mdk
- multiarch
- drop COPYING file as package is GPL (copyright is included in common-licenses)
- spec cosmetics

* Thu Feb 10 2005 Thierry Vignaud <tvignaud@mandrakesoft.com> 1.6-1mdk
- new release
- fix url

* Sat Jul 10 2004 Thierry Vignaud <tvignaud@mandrakesoft.com> 1.5-1mdk
- new release
- drop patch 0 (similar fix was comited upstream)

